// ctrlr8.h - definitions for compile-time options
//
// started: April 13, 2017  G. D. (Joe) Young <jyoung@islandnet.com>
//
// revised: Apr 18/17 - Add definitions for PTT line control
//          Apr 18/17 - from ctrlr14.h
//          May 12/17 - revised for ctrlr8 retrofit of features
//                    - re-organize groups under one #define
//          May 13/17 - alternate 4-modes assignment - sprints and FoxOr
//          May 18/17 - SSS mode definition for sprint centre beacon
//          May 26/17 - adjOverlap( ) macro added
//

// define macros for LED pin setup and operation for open drain output
#ifdef LPOLARITY_OD
  #define setLEDpin( ) {\
    pinMode( ledPin, INPUT );\
    digitalWrite( ledPin, LOW );}
  #define LEDpinON( ) (pinMode( ledPin, OUTPUT ))
  #define LEDpinOFF( ) (pinMode( ledPin, INPUT ))
#endif

// macros to setup and operate LED positive true
#ifdef LPOLARITY_POS
  #define setLEDpin( ) {\
    digitalWrite( ledPin, LOW );\
    pinMode( ledPin, OUTPUT );}
  #define LEDpinON( ) (digitalWrite( ledPin, HIGH ))
  #define LEDpinOFF( ) (digitalWrite( ledPin, LOW ))
#endif


// define macros to setup and operate Tx pin with open drain o/p
#ifdef TPOLARITY_OD
  #define setTxpin( ) {\
    pinMode( txPin, INPUT );\
    digitalWrite( txPin, LOW );}
  #define TxpinON( ) (pinMode( txPin, OUTPUT ))
  #define TxpinOFF( ) (pinMode( txPin, INPUT ))
#endif

// define macros to setup and operate Tx pin with active positive true
#ifdef TPOLARITY_POS
  #define setTxpin( ) {\
    digitalWrite( txPin, LOW );\
    pinMode( txPin, OUTPUT );}
  #define TxpinON( ) (digitalWrite( txPin, HIGH ))
  #define TxpinOFF( ) (digitalWrite( txPin, LOW ))
#endif

// define macros to setup and operate Tx pin with active negative true
#ifdef TPOLARITY_NEG
  #define setTxpin( ) {\
    digitalWrite( txPin, HIGH );\
    pinMode( txPin, OUTPUT );}
  #define TxpinON( ) (digitalWrite( txPin, LOW ))
  #define TxpinOFF( ) (digitalWrite( txPin, HIGH ))
#endif

// macro handling adjustment of on/off times by length of MOx
#ifdef ADJ_OVERLAP
 #define adjOverlap( ) {\
  if( fmode == SPS || fmode == NOR ) {\
    word adjsec = ( ( 24+(thisfox<<1) )*120 + 500 )/ADJ_OVERLAP;\
    onTime -= adjsec;\
    offTime += adjsec;\
  }\
  if( fmode == SPF || fmode == FOF ) {\
    word adjsec = ( ( 24+(thisfox<<1) )*87 + 500 )/ADJ_OVERLAP;\
    onTime -= adjsec;\
    offTime += adjsec;\
  }}
#else
 #define adjOverlap( ) ("")
#endif

// mode assignments depend on number of select pins used
#if NRMODEBITS == 3
  #define SPS  1   // sprint slow
  #define SPF  6   // sprint fast
  #define FOS  0   // FoxOr slow
  #define FOF  7   // FoxOr fast
  #define BEA  2   // beacon
  #define NOR  3   // normal 1-4 min
  #define NU1  4   // not used
//  #define NU2  5   // not used
  #define SSS  5   // sprint centre beacon
#elif NRMODEBITS == 2 && !defined ALTMODES1BIT2
  #define SPS 0
  #define SPF 1
  #define BEA 2
  #define NOR 3
  #define NU1 8   // handle mode names that will not occur...
  #define SSS 8   //  ..don't want them being used as legal values
  #define FOS 8
  #define FOF 8
#elif NRMODEBITS == 2 && defined ALTMODES1BIT2
  #define FOS 0
  #define SPS 1
  #define SPF 2
  #define FOF 3
  #define BEA 8   // handle mode names that will not occur...
  #define NOR 8
  #define NU1 8 
  #define SSS 8 
#elif NRMODEBITS == 1
  #define FOS 0
  #define FOF 1
  #define NU1 8   // handle mode names that will not occur
  #define SSS 8
  #define SPS 8
  #define SPF 8
  #define BEA 8
  #define NOR 8
#else
  #error NRMODEBITS must be 3, 2, or 1
#endif




